pub struct BusyBlock {
pub start: DateTime<Utc>,
pub end: DateTime<Utc>,
pub source_count: usize,
}Expand description
A merged busy block in the unified availability view.
Fields
start: DateTime<Utc>Start of the busy period.
end: DateTime<Utc>End of the busy period.
source_count: usizeNumber of source streams that contributed events to this block.
Set to 0 when privacy is Opaque.